@@ -6,7 +6,7 @@ import configparser
 from pathlib import Path
 from typing import Dict, Optional, Any, Callable
 
-from .i18n import _
+from .i18n import translate
 
 
 DEFAULT_CONFIG_ENCODING = 'utf-8'
@@ -15,7 +15,7 @@ DEFAULT_CONFIG_ENCODING = 'utf-8'
 RUNNING_AS_ROOT = os.geteuid() == 0
 
 
-VERSION = '1.9-dev'
+VERSION = '1.10-dev'
 
 _USER_CACHE_HOME = os.environ.get(
     "XDG_CACHE_HOME",
@@ -46,6 +46,11 @@ if RUNNING_AS_ROOT:
 else:
     AUR_REPOS_CACHE_PATH = os.path.join(DATA_ROOT, 'aur_repos')
 
+if RUNNING_AS_ROOT:
+    BUILD_DEPS_LOCK = os.path.join(_USER_CACHE_HOME, 'pikaur_build_deps.lock')
+else:
+    BUILD_DEPS_LOCK = '/tmp/pikaur_build_deps.lock'
+
 
 def get_config_path() -> str:
     config_flag = '--pikaur-config'
@@ -394,8 +399,8 @@ class PikaurConfig():
                 if old_value_was_migrated or old_value_was_removed:
                     print(' '.join([
                         '::',
-                        _("warning:"),
-                        _('Migrating [{}]{} config option to [{}]{} = "{}"...').format(
+                        translate("warning:"),
+                        translate('Migrating [{}]{} config option to [{}]{} = "{}"...').format(
                             section_name, option_name,
                             new_section_name, new_option_name,
                             cls._config[new_section_name][new_option_name]
