@@ -18,11 +18,11 @@ import pyalpm
 
 from .args import parse_args
 from .config import PikaurConfig
-from .i18n import _
+from .i18n import translate
 from .pprint import print_stderr, color_line, print_error, bold_line
 
 if TYPE_CHECKING:
-    # pylint: disable=unused-import,cyclic-import
+    # pylint: disable=cyclic-import
     from .aur import AURPackageInfo  # noqa
 
 
@@ -36,29 +36,44 @@ class ComparableType:
 
     __ignore_in_eq__: Tuple[str, ...] = tuple()
 
-    def _key_not_exists(self, key):
-        return getattr(self, key, NOT_FOUND_ATOM) is NOT_FOUND_ATOM
-
     __hash__ = object.__hash__
+    __compare_stack__: Optional[List[Any]] = None
+
+    @property
+    def public_vars(self):
+        return {
+            var: val for var, val in vars(self).items()
+            if not var.startswith('__')
+        }
 
     def __eq__(self, other):
         if not isinstance(other, self.__class__):
-            raise TypeError(f'{other} is not an instance of {self.__class__}')
-        if not self.__ignore_in_eq__:
+            raise TypeError(
+                f"'{other.__class__.__name__}' is not an instance of '{self.__class__.__name__}'"
+            )
+        if not self.__compare_stack__:
+            self.__compare_stack__ = []
+        elif other in self.__compare_stack__:
             return super().__eq__(other)
+        self.__compare_stack__.append(other)
         self_vars = {}
-        self_vars.update(vars(self))
+        self_vars.update(self.public_vars)
         other_vars = {}
-        other_vars.update(vars(other))
+        other_vars.update(other.public_vars)
         for var_dict in (self_vars, other_vars):
             for skip_prop in self.__ignore_in_eq__:
                 if skip_prop in var_dict:
                     del var_dict[skip_prop]
-        return self_vars == other_vars
+        result = self_vars == other_vars
+        self.__compare_stack__ = None
+        return result
 
 
 class DataType(ComparableType):
 
+    def _key_not_exists(self, key):
+        return getattr(self, key, NOT_FOUND_ATOM) is NOT_FOUND_ATOM
+
     def __init__(self, **kwargs) -> None:
         for key, value in kwargs.items():
             setattr(self, key, value)
@@ -249,7 +264,7 @@ def open_file(
         encoding = detect_bom_type(file_path)
     if encoding:
         kwargs['encoding'] = encoding
-    return codecs.open(  # pylint: disable=consider-using-with
+    return codecs.open(
         file_path, mode, errors='ignore', **kwargs
     )
 
@@ -330,7 +345,7 @@ def run_with_sudo_loop(function: Callable) -> Optional[Any]:
         finally:
             pool.terminate()
         if catched_exc:
-            raise catched_exc  # pylint: disable=raising-bad-type
+            raise catched_exc
         if result:
             return result
         return None
@@ -350,12 +365,12 @@ def check_systemd_dynamic_users() -> bool:  # pragma: no cover
 def check_runtime_deps(dep_names: Optional[List[str]] = None) -> None:
     if sys.version_info.major < 3 or sys.version_info.minor < 7:
         print_error(
-            _("pikaur requires Python >= 3.7 to run."),
+            translate("pikaur requires Python >= 3.7 to run."),
         )
         sys.exit(65)
     if running_as_root() and not check_systemd_dynamic_users():
         print_error(
-            _("pikaur requires systemd >= 235 (dynamic users) to be run as root."),
+            translate("pikaur requires systemd >= 235 (dynamic users) to be run as root."),
         )
         sys.exit(65)
     if not dep_names:
@@ -368,6 +383,6 @@ def check_runtime_deps(dep_names: Optional[List[str]] = None) -> None:
         if not shutil.which(dep_bin):
             print_error("'{}' {}.".format(  # pylint: disable=consider-using-f-string
                 bold_line(dep_bin),
-                _("executable not found")
+                translate("executable not found")
             ))
             sys.exit(2)
