@@ -10,7 +10,7 @@ from typing import (
 from pycman.config import PacmanConfig as PycmanConfig
 import pyalpm
 
-from .i18n import _
+from .i18n import translate
 from .pacman_i18n import _p
 from .core import DataType, PackageSource
 from .version import VersionMatcher
@@ -23,7 +23,7 @@ from .prompt import retry_interactive_command_or_exit, retry_interactive_command
 
 
 if TYPE_CHECKING:
-    # pylint: disable=unused-import,cyclic-import
+    # pylint: disable=cyclic-import
     from .aur import AURPackageInfo  # noqa
 
 
@@ -98,7 +98,7 @@ class PacmanPrint(DataType):
 class PacmanConfig(PycmanConfig):
 
     def __init__(self) -> None:
-        super().__init__(conf='/etc/pacman.conf')
+        super().__init__(conf=parse_args().config or '/etc/pacman.conf')
 
 
 class ProvidedDependency(DataType):
@@ -126,7 +126,7 @@ DB_LOCK_LOCAL = Lock()
 class DbLockRepo():
 
     def __enter__(self) -> None:
-        DB_LOCK_REPO.acquire()  # pylint: disable=consider-using-with
+        DB_LOCK_REPO.acquire()
 
     def __exit__(self, *_exc_details) -> None:
         if DB_LOCK_REPO.locked():
@@ -139,7 +139,7 @@ class DbLockRepo():
 class DbLockLocal():
 
     def __enter__(self) -> None:
-        DB_LOCK_LOCAL.acquire()  # pylint: disable=consider-using-with
+        DB_LOCK_LOCAL.acquire()
 
     def __exit__(self, *_exc_details) -> None:
         if DB_LOCK_LOCAL.locked():
@@ -312,7 +312,7 @@ class PackageDB(PackageDBCommon):
         if not cls._packages_list_cache.get(PackageSource.LOCAL):
             with DbLockLocal():
                 if not quiet:
-                    print_stderr(_("Reading local package database..."))
+                    print_stderr(translate("Reading local package database..."))
                 cls._packages_list_cache[PackageSource.LOCAL] = cls.search_local('')
         return cls._packages_list_cache[PackageSource.LOCAL]
 
@@ -367,7 +367,7 @@ class PackageDB(PackageDBCommon):
         if not cls._packages_list_cache.get(PackageSource.REPO):
             with DbLockRepo():
                 if not quiet:
-                    print_stderr(_("Reading repository package databases..."))
+                    print_stderr(translate("Reading repository package databases..."))
                 cls._packages_list_cache[PackageSource.REPO] = cls.search_repo(
                     search_query=''
                 )
